@@ -57,6 +57,7 @@ import pymongo
 from fireworks import Firework, FireTaskBase
 from collections import defaultdict
 import jinja2
+import sysconfig
 
 
 # Create connection to database
@@ -587,7 +588,7 @@ install(TARGETS %(h)s DESTINATION ${CMAKE_INSTALL_PREFIX}/lib )
             f.close()
 
             from subprocess import call
-            call(['cmake', '.'])
+            call(['cmake', f"-DPYTHON_INCLUDE_DIR={sysconfig.get_path('include')}", f"-DPYTHON_LIBRARY={sysconfig.get_config_var('LIBDIR')}", "."])
             call(['make'])
             os.chdir('..')
 
